==> release.12.0.73.1.tgz: prontus/cpan/js-local/TagsFid.class.js <==
var TagsFid = {
    // Parametros de este espacio :
    list_current: [],
    list_all: [],
    list_diff: [],
    list_all_corta: [],
    list_current_corta: [],
    tags_url: '',

    tmp_lista: [],
    // list_current_corta inicial se obtiene de los values agregados por prontus

    loadListaCorta: function() {
        var len_tmp_lista = TagsFid.tmp_lista.length;
        for (var i= 0; i < len_tmp_lista; i++) {
            var element = TagsFid.tmp_lista[i];
            TagsFid.list_current.push(element);
            var new_element = element.replace(/\d+\|/ig, '');
            TagsFid.list_current_corta.push(new_element);
        }
    },

    loadJson: function() {
        TagsFid.tags_url = "/" + Admin.prontus_id + "/cpan/procs/data4fids/tags.json?token=" + Date.now();
        $.getJSON(TagsFid.tags_url, function() {
            $("#loading").show();
        })
        .done(function(data) {
            TagsFid.doLoadJson(data);
        })
        .fail(function() {
            TagsFid.doLoadJson({});
        });
    },

    // usada en loadJson, tanto con success como con fail.
    doLoadJson: function(json) {
        if (Array.isArray(json)) {
            // ordenamos tags alfabeticamente ignorando case
            json.sort((a, b) => {
                const nameA = a.nom.toUpperCase(); // ignore upper and lowercase
                const nameB = b.nom.toUpperCase(); // ignore upper and lowercase
                if (nameA < nameB) {
                    return -1;
                }
                if (nameA > nameB) {
                    return 1;
                }

                // names must be equal
                return 0;
            });
        }

        // bloodHound
        var tagname = new Bloodhound({
            datumTokenizer: Bloodhound.tokenizers.whitespace,
            queryTokenizer: Bloodhound.tokenizers.whitespace,
            local: $.map(json, function(tag) {
                return tag.nom
            })
        });

        tagname.initialize();
        /*
         * Typeahead
         */

        var elt = $('#_temptags4');
        elt.tagsinput({
            typeaheadjs: {
                name: 'tagnames',
                source: tagname.ttAdapter(),
            },
            freeInput: false
        });

        // HACK: overrule hardcoded display inline-block of typeahead.js
        $(".twitter-typeahead").css('display', 'inline');
        // fin bloodhound

        for (var i = 0; i < json.length; i++) {
            var element = json[i];
            var value = element.id + "|" + element.nom;
            TagsFid.list_all.push(value);
            TagsFid.list_all_corta.push(element.nom);
        }

        TagsFid.tmp_lista = ($("#_temptags4").val()).split(",");

        $('#_temptags4').tagsinput('removeAll');

        $('#_temptags4').on('change', function(event) {
            var $element = $(event.target),
                $container = $element.closest('.tagname');
            if (!$element.data('tagsinput'))
                return;
            var val = $element.val();
            if (val === null)
                val = "null";
            $('code', $('pre.val', $container)).html(($.isArray(val) ? JSON.stringify(val) : "\"" + val.replace('"', '\\"') + "\""));
            $('code', $('pre.items', $container)).html(JSON.stringify($element.tagsinput('items')));
        }).trigger('change');

        TagsFid.loadListaCorta();
        TagsFid.loadTags();

        TagsFid.updateDiff();
        TagsFid.fastCreateTagList();
    },

    updateHidden: function(myarray) {
        // resetea los valores
        $('#_tags').val("");
        $('#_tags4fid').val("");
        var len_myarray = myarray.length;

        var i = 0;
        for (i; i < len_myarray; i++) {
            var element = myarray[i];
            // si tiene pipe , dejarlo , si no tiene pipe  cambiarlo :
            if (element.match(/\|/i)) {
                // viene con el pipe
                $('#_tags').val($('#_tags').val() + "," + element);
                $('#_tags4fid').val($('#_tags4fid').val() + "," + element);
            } else {
                var tag_index = $.inArray(element, TagsFid.list_all_corta);
                var new_element = TagsFid.list_all[tag_index];
                if (new_element) {
                    $('#_tags').val($('#_tags').val() + "," + new_element);
                    $('#_tags4fid').val($('#_tags4fid').val() + "," + new_element);
                }
            }
        }
    },

    diffArray: function(arr1, arr2) {
        // funcion que retorna la diferencia de los array A-B
        return arr1.concat(arr2).filter(function(val) {
            if (!(arr1.includes(val) && arr2.includes(val)))
                return val;
        })
    },

    updateDiff: function() {
        TagsFid.list_diff = TagsFid.diffArray(TagsFid.list_current, TagsFid.list_all);
        TagsFid.updateHidden(TagsFid.list_current);
        return;
    },

    loadTags: function() {
        $('#_temptags4').tagsinput('removeAll');
        var len_list_current_corta = TagsFid.list_current_corta.length;
        for (var i = 0; i < len_list_current_corta; i++) {
            $('#_temptags4').tagsinput('add', TagsFid.list_current_corta[i]);
            $('#_tags').val($('#_tags').val() + " " + TagsFid.list_current[i]);
        }
    },

    fastCreateTagList: function() {
        var len_list_all_corta = TagsFid.list_all_corta.length;
        var a = [];

        for (let i = 0; i < len_list_all_corta; i++) {
            let element = TagsFid.list_all_corta[i];
            a.push('<span class="pointer txtnextgray2 nextgray5 iblock mar-top-bot2 mar-lef-rig2 pad-top-bot4 pad-lef-rig10 pt9 monlight tagbutton text-center taglist-normal"> ' + element + '</span>');
        }

        document.getElementById("my_tag_buttons").innerHTML = a.join("");
        if (TagsFid.list_current_corta[0] != "") {
            var len_list_current_corta = TagsFid.list_current_corta.length;
            for (let i = 0; i < len_list_current_corta; i++) {
                let element = TagsFid.list_current_corta[i];

                $(".tagbutton:contains('" + element + "')").each(function(index, value) {
                    var tag_test = $.trim($(this).text());
                    if (tag_test.indexOf(element) > -1) {
                        $(this).removeClass("taglist-normal");
                        $(this).addClass("taglist-added");

                    }
                });
            }
        }
    },

    createTagList: function() {
        var len_list_all_corta = TagsFid.list_all_corta.length;
        for (let i = 0; i < len_list_all_corta; i++) {
            let element = TagsFid.list_all_corta[i];
            $(".my_tag_buttons").append('<span class="col-md-11 tagbutton text-center taglist-normal"> ' + element + '</span>');
        }

        // por cada elemento de lista_current_corta, si existe en list_all_corta, cambiar la clase a added.
        if (!TagsFid.list_current_corta[0] == "") {
            var len_list_current_corta = TagsFid.list_current_corta.length;
            for (let i = 0; i < len_list_current_corta; i++) {
                let element = TagsFid.list_current_corta[i];

                $(".tagbutton:contains('" + element + "')").each(function(index, value) {
                    var tag_test = $.trim($(this).text());
                    if (tag_test.indexOf(element) > -1) {
                        $(this).removeClass("taglist-normal");
                        $(this).addClass("taglist-added");

                    }
                });
            }
        }
    },

    clearTagList: function() {
        $(".tagbutton").detach();
    },

    addTag: function(element) {
        element = TagsFid.clearSpaces(element);
        // agrega tag desde lista a current_list.
        // el nombre viene en formato corto , convertir a formato largo :
        var tag_index = $.inArray(element, TagsFid.list_all_corta);
        var new_element = TagsFid.list_all[tag_index];
        if (new_element) {
            if (jQuery.inArray(new_element, TagsFid.list_current) < 0) {
                // no se encontró, hacemos el push y actualizamos temptags.
                // y se ejecuta la bateria de funciones.
                TagsFid.list_current.push(new_element);
                TagsFid.list_current_corta.push(element);

                // cambiar el color.
                // remover clase normal y agregar clase added
                //"\b"+element+"\b"

                $(".tagbutton:contains('" + element + "')").each(function(index, value) {
                    var tag_test = $.trim($(this).text());
                    if (tag_test.indexOf(element) > -1) {
                        $('#_temptags4').tagsinput('add', element);
                        $(this).removeClass("taglist-normal");
                        $(this).addClass("taglist-added");
                    }
                });

                TagsFid.updateDiff();
            } else {
                $(".tagbutton:contains('" + element + "')").each(function(index, value) {
                    var tag_test = $.trim($(this).text());
                    if (tag_test.indexOf(element) > -1) {
                        if ($(".tagbutton:contains('" + element + "')").hasClass("taglist-added")) {
                            $('#_temptags4').tagsinput('remove', element);
                            $(this).removeClass("taglist-added");
                            $(this).addClass("taglist-normal");
                        }
                    }
                });
            }
        }
    },

    removeTag: function(element) {
        var tag_index = $.inArray(element, TagsFid.list_all_corta);
        var new_element = TagsFid.list_all[tag_index];
        if (tag_index > -1) {
            TagsFid.list_current.splice(TagsFid.list_current.indexOf(new_element), 1);
            TagsFid.list_current_corta.splice(TagsFid.list_current_corta.indexOf(element), 1);
            TagsFid.updateDiff();
            if ($(".tagbutton:contains('" + element + "')").hasClass("taglist-added")) {
                $(".tagbutton:contains('" + element + "')").each(function(index, value) {
                    var tag_test = $.trim($(this).text());
                    if (tag_test.indexOf(element) > -1) {
                        $(this).removeClass("taglist-added");
                        $(this).addClass("taglist-normal");
                    }
                })
                return;
            }
            return 1;
        } else {
            return 0;
        }
    },

    clearSpaces: function(element) {
        if (!element) {
            return
        } else {
            return element.replace(/^\s+|\s+$/gm, '');
        }


    },

    init: function() {
        if ($("#_temptags4").length <1 ) { return }

        TagsFid.loadJson();
        $("#tags_search_input,#_temptags4").keyup(function() {
            var search_text = $("#tags_search_input").val()
            if (search_text.length >= 3) {
                // hide main block (so one redraw)
                $('.tagbutton').css("display", "none");

                $('.tagbutton').each(function() {
                    if ($(this).text().toUpperCase().indexOf(
                            search_text.toUpperCase()) != -1) {
                        $(this).show();
                    }
                });
                // show main block (so one redraw!)
            } else if (search_text.length == 0) {
                $('.tagbutton').css("display", "block");
            }
        });

        $(".my_tag_buttons").on("mouseover", ".tagbutton", function() {
            $(this).removeClass("tag-mouseOut");
            $(this).addClass("tag-mouseIn");

        });

        $(".my_tag_buttons").on("mouseout", ".tagbutton", function() {
            $(this).removeClass("tag-mouseIn");
            $(this).addClass("tag-mouseOut");
        });

        $(".my_tag_buttons").on("click", ".tagbutton", function() {
            var text = $(this).text();
            TagsFid.addTag(text);
        });

        $('#_temptags4').on('itemRemoved', function(event) {
            // event.item: contains the item
            TagsFid.removeTag(event.item);
        });
        $('#_temptags4').on('itemAdded', function(event) {
            // event.item: contains the item
            TagsFid.addTag(event.item);
        });
    }
}

$(document).ready(function() {
    TagsFid.init();
});

==> release.12.3.1.2.tgz: prontus/cpan/js-local/TagsFid.class.js <==
var TagsFid = {
    // Parametros de este espacio :
    list_current: [],
    list_all: [],
    list_diff: [],
    list_all_corta: [],
    list_current_corta: [],
    tags_url: '',

    tmp_lista: [],
    // list_current_corta inicial se obtiene de los values agregados por prontus

    loadListaCorta: function() {
        var len_tmp_lista = TagsFid.tmp_lista.length;
        for (var i= 0; i < len_tmp_lista; i++) {
            var element = TagsFid.tmp_lista[i];
            TagsFid.list_current.push(element);
            var new_element = element.replace(/\d+\|/ig, '');
            TagsFid.list_current_corta.push(new_element);
        }
    },

    loadJson: function() {
        TagsFid.tags_url = "/" + Admin.prontus_id + "/cpan/data4fids/tags.json?token=" + Date.now();
        $.getJSON(TagsFid.tags_url, function() {
            $("#loading").show();
        })
        .done(function(data) {
            TagsFid.doLoadJson(data);
        })
        .fail(function() {
            TagsFid.doLoadJson({});
        });
    },

    // usada en loadJson, tanto con success como con fail.
    doLoadJson: function(json) {
        if (Array.isArray(json)) {
            // ordenamos tags alfabeticamente ignorando case
            json.sort((a, b) => {
                const nameA = a.nom.toUpperCase(); // ignore upper and lowercase
                const nameB = b.nom.toUpperCase(); // ignore upper and lowercase
                if (nameA < nameB) {
                    return -1;
                }
                if (nameA > nameB) {
                    return 1;
                }

                // names must be equal
                return 0;
            });
        }

        // bloodHound
        var tagname = new Bloodhound({
            datumTokenizer: Bloodhound.tokenizers.whitespace,
            queryTokenizer: Bloodhound.tokenizers.whitespace,
            local: $.map(json, function(tag) {
                return tag.nom
            })
        });

        tagname.initialize();
        /*
         * Typeahead
         */

        var elt = $('#_temptags4');
        elt.tagsinput({
            typeaheadjs: {
                name: 'tagnames',
                source: tagname.ttAdapter(),
            },
            freeInput: false
        });

        // HACK: overrule hardcoded display inline-block of typeahead.js
        $(".twitter-typeahead").css('display', 'inline');
        // fin bloodhound

        for (var i = 0; i < json.length; i++) {
            var element = json[i];
            var value = element.id + "|" + element.nom;
            TagsFid.list_all.push(value);
            TagsFid.list_all_corta.push(element.nom);
        }

        TagsFid.tmp_lista = ($("#_temptags4").val()).split(",");

        $('#_temptags4').tagsinput('removeAll');

        $('#_temptags4').on('change', function(event) {
            var $element = $(event.target),
                $container = $element.closest('.tagname');
            if (!$element.data('tagsinput'))
                return;
            var val = $element.val();
            if (val === null)
                val = "null";
            $('code', $('pre.val', $container)).html(($.isArray(val) ? JSON.stringify(val) : "\"" + val.replace('"', '\\"') + "\""));
            $('code', $('pre.items', $container)).html(JSON.stringify($element.tagsinput('items')));
        }).trigger('change');

        TagsFid.loadListaCorta();
        TagsFid.loadTags();

        TagsFid.updateDiff();
        TagsFid.fastCreateTagList();
    },

    updateHidden: function(myarray) {
        // resetea los valores
        $('#_tags').val("");
        $('#_tags4fid').val("");
        var len_myarray = myarray.length;

        var i = 0;
        for (i; i < len_myarray; i++) {
            var element = myarray[i];
            // si tiene pipe , dejarlo , si no tiene pipe  cambiarlo :
            if (element.match(/\|/i)) {
                // viene con el pipe
                $('#_tags').val($('#_tags').val() + "," + element);
                $('#_tags4fid').val($('#_tags4fid').val() + "," + element);
            } else {
                var tag_index = $.inArray(element, TagsFid.list_all_corta);
                var new_element = TagsFid.list_all[tag_index];
                if (new_element) {
                    $('#_tags').val($('#_tags').val() + "," + new_element);
                    $('#_tags4fid').val($('#_tags4fid').val() + "," + new_element);
                }
            }
        }
    },

    diffArray: function(arr1, arr2) {
        // funcion que retorna la diferencia de los array A-B
        return arr1.concat(arr2).filter(function(val) {
            if (!(arr1.includes(val) && arr2.includes(val)))
                return val;
        })
    },

    updateDiff: function() {
        TagsFid.list_diff = TagsFid.diffArray(TagsFid.list_current, TagsFid.list_all);
        TagsFid.updateHidden(TagsFid.list_current);
        return;
    },

    loadTags: function() {
        $('#_temptags4').tagsinput('removeAll');
        var len_list_current_corta = TagsFid.list_current_corta.length;
        for (var i = 0; i < len_list_current_corta; i++) {
            $('#_temptags4').tagsinput('add', TagsFid.list_current_corta[i]);
            $('#_tags').val($('#_tags').val() + " " + TagsFid.list_current[i]);
        }
    },

    fastCreateTagList: function() {
        var len_list_all_corta = TagsFid.list_all_corta.length;
        var a = [];

        for (let i = 0; i < len_list_all_corta; i++) {
            let element = TagsFid.list_all_corta[i];
            a.push('<span class="pointer txtnextgray2 nextgray5 iblock mar-top-bot2 mar-lef-rig2 pad-top-bot4 pad-lef-rig10 pt9 monlight tagbutton text-center taglist-normal"> ' + element + '</span>');
        }

        document.getElementById("my_tag_buttons").innerHTML = a.join("");
        if (TagsFid.list_current_corta[0] != "") {
            var len_list_current_corta = TagsFid.list_current_corta.length;
            for (let i = 0; i < len_list_current_corta; i++) {
                let element = TagsFid.list_current_corta[i];

                $(".tagbutton:contains('" + element + "')").each(function(index, value) {
                    var tag_test = $.trim($(this).text());
                    if (tag_test.indexOf(element) > -1) {
                        $(this).removeClass("taglist-normal");
                        $(this).addClass("taglist-added");

                    }
                });
            }
        }
    },

    createTagList: function() {
        var len_list_all_corta = TagsFid.list_all_corta.length;
        for (let i = 0; i < len_list_all_corta; i++) {
            let element = TagsFid.list_all_corta[i];
            $(".my_tag_buttons").append('<span class="col-md-11 tagbutton text-center taglist-normal"> ' + element + '</span>');
        }

        // por cada elemento de lista_current_corta, si existe en list_all_corta, cambiar la clase a added.
        if (!TagsFid.list_current_corta[0] == "") {
            var len_list_current_corta = TagsFid.list_current_corta.length;
            for (let i = 0; i < len_list_current_corta; i++) {
                let element = TagsFid.list_current_corta[i];

                $(".tagbutton:contains('" + element + "')").each(function(index, value) {
                    var tag_test = $.trim($(this).text());
                    if (tag_test.indexOf(element) > -1) {
                        $(this).removeClass("taglist-normal");
                        $(this).addClass("taglist-added");

                    }
                });
            }
        }
    },

    clearTagList: function() {
        $(".tagbutton").detach();
    },

    addTag: function(element) {
        element = TagsFid.clearSpaces(element);
        // agrega tag desde lista a current_list.
        // el nombre viene en formato corto , convertir a formato largo :
        var tag_index = $.inArray(element, TagsFid.list_all_corta);
        var new_element = TagsFid.list_all[tag_index];
        if (new_element) {
            if (jQuery.inArray(new_element, TagsFid.list_current) < 0) {
                // no se encontró, hacemos el push y actualizamos temptags.
                // y se ejecuta la bateria de funciones.
                TagsFid.list_current.push(new_element);
                TagsFid.list_current_corta.push(element);

                // cambiar el color.
                // remover clase normal y agregar clase added
                //"\b"+element+"\b"

                $(".tagbutton:contains('" + element + "')").each(function(index, value) {
                    var tag_test = $.trim($(this).text());
                    if (tag_test.indexOf(element) > -1) {
                        $('#_temptags4').tagsinput('add', element);
                        $(this).removeClass("taglist-normal");
                        $(this).addClass("taglist-added");
                    }
                });

                TagsFid.updateDiff();
            } else {
                $(".tagbutton:contains('" + element + "')").each(function(index, value) {
                    var tag_test = $.trim($(this).text());
                    if (tag_test.indexOf(element) > -1) {
                        if ($(".tagbutton:contains('" + element + "')").hasClass("taglist-added")) {
                            $('#_temptags4').tagsinput('remove', element);
                            $(this).removeClass("taglist-added");
                            $(this).addClass("taglist-normal");
                        }
                    }
                });
            }
        }
    },

    removeTag: function(element) {
        var tag_index = $.inArray(element, TagsFid.list_all_corta);
        var new_element = TagsFid.list_all[tag_index];
        if (tag_index > -1) {
            TagsFid.list_current.splice(TagsFid.list_current.indexOf(new_element), 1);
            TagsFid.list_current_corta.splice(TagsFid.list_current_corta.indexOf(element), 1);
            TagsFid.updateDiff();
            if ($(".tagbutton:contains('" + element + "')").hasClass("taglist-added")) {
                $(".tagbutton:contains('" + element + "')").each(function(index, value) {
                    var tag_test = $.trim($(this).text());
                    if (tag_test.indexOf(element) > -1) {
                        $(this).removeClass("taglist-added");
                        $(this).addClass("taglist-normal");
                    }
                })
                return;
            }
            return 1;
        } else {
            return 0;
        }
    },

    clearSpaces: function(element) {
        if (!element) {
            return
        } else {
            return element.replace(/^\s+|\s+$/gm, '');
        }


    },

    init: function() {
        if ($("#_temptags4").length <1 ) { return }

        TagsFid.loadJson();
        $("#tags_search_input,#_temptags4").keyup(function() {
            var search_text = $("#tags_search_input").val()
            if (search_text.length >= 3) {
                // hide main block (so one redraw)
                $('.tagbutton').css("display", "none");

                $('.tagbutton').each(function() {
                    if ($(this).text().toUpperCase().indexOf(
                            search_text.toUpperCase()) != -1) {
                        $(this).show();
                    }
                });
                // show main block (so one redraw!)
            } else if (search_text.length == 0) {
                $('.tagbutton').css("display", "block");
            }
        });

        $(".my_tag_buttons").on("mouseover", ".tagbutton", function() {
            $(this).removeClass("tag-mouseOut");
            $(this).addClass("tag-mouseIn");

        });

        $(".my_tag_buttons").on("mouseout", ".tagbutton", function() {
            $(this).removeClass("tag-mouseIn");
            $(this).addClass("tag-mouseOut");
        });

        $(".my_tag_buttons").on("click", ".tagbutton", function() {
            var text = $(this).text();
            TagsFid.addTag(text);
        });

        $('#_temptags4').on('itemRemoved', function(event) {
            // event.item: contains the item
            TagsFid.removeTag(event.item);
        });
        $('#_temptags4').on('itemAdded', function(event) {
            // event.item: contains the item
            TagsFid.addTag(event.item);
        });
    }
}

$(document).ready(function() {
    TagsFid.init();
});
